Instrument
==========

Base Classes and Calibration Tokens
-------------------------------------

.. automodule:: unite.instrument.base
   :members:
   :undoc-members:
   :show-inheritance:

Instrument Configuration
-------------------------

.. automodule:: unite.instrument.config
   :members:
   :undoc-members:
   :show-inheritance:

Generic Implementations
-----------------------

.. automodule:: unite.instrument.generic
   :members:
   :undoc-members:
   :show-inheritance:

NIRSpec Dispersers
------------------

.. automodule:: unite.instrument.nirspec.disperser
   :members:
   :undoc-members:
   :show-inheritance:

SDSS Disperser
--------------

.. automodule:: unite.instrument.sdss.disperser
   :members:
   :undoc-members:
   :show-inheritance:
